<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="ReportDBMS.xsl"/>
	
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<!-- BEGIN statistics section -->
	<xsl:template match="optimreport:statistics">
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">statistics_detail</xsl:with-param>
		</xsl:call-template>
		
		<!-- Statistics Banner -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Statistical Information</xsl:with-param>
			<xsl:with-param name="containerId">statistics_container</xsl:with-param>
			<xsl:with-param name="containerClass">statistics_container_class</xsl:with-param>
			<xsl:with-param name="anchor">statistics_detail</xsl:with-param>
			<xsl:with-param name="closeByDefault">true</xsl:with-param>
		</xsl:call-template>
		
		<!-- Statistics Contents -->
		<div id="statistics_container" class="section_container statistics_container_class" style="display:none;" inAllAction="true">
			<xsl:for-each select="optimreport:statistic">
				<!-- Print the step number and name, allow user to expand this section -->
				<table class="statistic_headers">
					<tr>
						<td colspan="2" class="archive_statistic_header_name  drop_down_hover" istitle="yes" onClick="toggleById('{generate-id(@name)}', event); swap('{generate-id(@name)}DetailsArrow','{generate-id(@name)}', event)">

							<!-- Javascript controls to expand and collapse the section -->
							<a id="JSLanding{generate-id(@name)}" />

							<xsl:call-template name="arrow">
								<xsl:with-param name="id" select="concat(generate-id(@name),'DetailsArrow')" />
								<xsl:with-param name="isExpand">false</xsl:with-param>
							</xsl:call-template>
							<!-- End of Javascript controls -->

							<xsl:text>&#160;&#160;&#160;</xsl:text>
							<xsl:choose>
								<xsl:when test="number(@stepNumber) &gt; 0">
									<xsl:text>Step </xsl:text>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@stepNumber"/>
									</xsl:call-template>
									<xsl:text>:</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<!-- If this is the delete, only show table name-->
									<xsl:if test="not(contains(name(../..), DeleteReport))">
										<xsl:text>Reference Table</xsl:text>
										<xsl:text>: </xsl:text>
									</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@name"/>
							</xsl:call-template>
						</td>
					</tr>
				</table>
				<!-- Section to be expanded, should the above be clicked -->
				<div id="{generate-id(@name)}" class="statistic_table_content_block" style="display: none;" inAllAction="true">
					<!-- This table helps us auto-format the tables within them -->
					<div class="statistics_container">
						<xsl:variable name="nodeName" select="name(../..)"/>
						<xsl:choose>
							<xsl:when test="contains(name(../..), 'Delete')">
								<!-- Fourth table in Statistics Section for Delete -->
								<table class="statistics_table">
									<tr>
										<th>
											Rows to delete
										</th>
										<td>
											<xsl:choose>
												<xsl:when test="number(@rowsToDelete) = number(@rowsToDelete)">
													<xsl:value-of select="@rowsToDelete"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>0</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
									<tr>
										<th>
											Array deletes
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@arrayDeletes"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Row archive actions
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@rowActions"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Locked table
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@lockTable"/>
											</xsl:call-template>
										</td>
									</tr>
								</table>

								<table class="statistics_table">
									<tr>
										<th>
											Compare row contents
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@compareRowContent"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Include Lobs in compare
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@includeLobsInCompare"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Commit frequency
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@commitFrequency"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Table indexes
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@numberOfTableIndexes"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Run in parallel
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@runInParallel"/>
											</xsl:call-template>
										</td>
									</tr>
								</table>

								<table class="statistics_table">
									<tr>
										<th>
											Key per delete statement
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@keysPerDeleteStatement"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Access strategy
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@accessStrategy"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Open cursor
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@openCursors"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Row fetched
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@rowsFetched"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Delete statements
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@numberOfDeleteStatements"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Time in database reads
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@timeInDatabaseReads"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
								</table>
								
								<table class="statistics_table">
									<tr>
										<th>
											Time in database deletes
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@timeInDatabaseDeletes"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Time in database archive actions
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@timeInActions"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
											<xsl:text>%</xsl:text>
										</td>
									</tr>
									<tr>
										<th>
											Start time
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="substring-before(@startTime, '.')"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											End time
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="substring-before(@endTime, '.')"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Process time
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="substring-before(@processTime, '.')"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Rows per second
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@rowsPerSecond"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											Delete buffer size per connection
										</th>
										<td>
											<xsl:call-template name="fileSizeFormatting">
												<xsl:with-param name="fileSize" select="number(@deleteBufferSizePerConnection)"/>
												<xsl:with-param name="start">TB</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
								</table>
							</xsl:when>
							<xsl:otherwise>

								<!-- First Table in Statistics Section - 6 Fields -->
								<table class="statistics_table">
									<tr>
										<th>
											<xsl:text>Child strategy</xsl:text>
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@childStrategy"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Column count</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@columnCount"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Cycle</xsl:text>
										</th>
										<td>
											<xsl:call-template name="booleanFormat">
												<xsl:with-param name="value" select="@cycle"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Database connections</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@databaseConnections"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Estimated row count</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@estimatedRowCount"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Fetch buffer</xsl:text>
										</th>
										<td>
											<xsl:call-template name="fileSizeFormatting">
												<xsl:with-param name="fileSize" select="@fetchBuffer"/>
												<xsl:with-param name="start">TB</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
								</table>

								<table class="statistics_table">
									<!-- Second Table in Statistics Section - 5 Fields -->
									<tr>
										<th>
											<xsl:text>Foreign key index</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@foreignKeyIndex"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Foreign key no index</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@foreignKeyNoIndex"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>LOBs </xsl:text>
										</th>
										<td>
											<xsl:call-template name="booleanFormat">
												<xsl:with-param name="value" select="@lobColumns"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Parent strategy</xsl:text>
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@parentStrategy"/>
											</xsl:call-template>
										</td>
									</tr>
								</table>

								<!-- Third table in Statistics Section - 7 Fields -->
								<table class="statistics_table">
									<tr>
										<th>
											<xsl:text>Primary key index</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@primaryKeyIndex"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Primary key no index</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@primaryKeyNoIndex"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Row length</xsl:text>
										</th>
										<td>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@rowLength"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Select uncommitted read</xsl:text>
										</th>
										<td>
											<xsl:call-template name="booleanFormat">
												<xsl:with-param name="value" select="@selectUniqueRecord"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Vendor</xsl:text>
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@vendor"/>
											</xsl:call-template>
										</td>
									</tr>
									<tr>
										<th>
											<xsl:text>Version</xsl:text>
										</th>
										<td>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@version"/>
											</xsl:call-template>
										</td>
									</tr>
								</table>

							</xsl:otherwise>
						</xsl:choose>
					</div>
					<!-- Now do relationship statistics processing -->
					<xsl:apply-templates select="optimreport:relationship" />
					<!-- Now do DBMSAccess statistics processing -->
					<xsl:apply-templates select="optimreport:dbmsAccess" />
				</div>
			</xsl:for-each>
		</div>
	</xsl:template>
	<!-- END statistics section -->
	
	<!-- BEGIN relationship statistics processing -->
	<xsl:template match="optimreport:relationship">
		<div>
			<!-- Minor header based on if we used method Relationship or Primary Key -->
			<h3 class="table_of_contents_header_text">
				<xsl:choose>
					<xsl:when test="../@method = 'Relationship'"> 
						<xsl:text>Relationship - </xsl:text>
						<xsl:call-template name="stringCheck">
							<xsl:with-param name="value" select="@name"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Primary Key</xsl:text>	
					</xsl:otherwise>
				</xsl:choose>
			</h3>
		</div>

		<div class="statistics_container">
			<div>
				<xsl:choose>
					<xsl:when test="(not(@db2Cost) and not(@db2ScanCost))">
						<table class="statistics_table">
							<tr>
								<th>
									<xsl:text>Access</xsl:text>
								</th>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@access"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>
									<xsl:text>Direction</xsl:text>
								</th>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@direction"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>
									<xsl:text>Index</xsl:text>
								</th>
								<td>
									<xsl:call-template name="booleanFormat">
										<xsl:with-param name="value" select="@index"/>
									</xsl:call-template>
								</td>
							</tr>
						</table>
					</xsl:when>
					<xsl:otherwise>
						<!-- First Table in Relationship/Primary Key Section - 3 Fields -->
						<table class="statistics_table">
							<tr>
								<th>
									<xsl:text>Access</xsl:text>
								</th>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@access"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>
									<xsl:text>DB2 lookup cost</xsl:text>
								</th>
								<td>
									<xsl:choose>
										<xsl:when test="number(@db2Cost) = number(@db2Cost)">
											<xsl:choose>
												<xsl:when test="@db2Cost &lt; 0">
													<xsl:text>Runstats not run</xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:call-template name="numberFormat">
														<xsl:with-param name="number" select="@db2Cost"/>
														<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
													</xsl:call-template>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Runstats not available</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>
							</tr>
							<tr>
								<th>
									<xsl:text>DB2 scan cost</xsl:text>
								</th>
								<td>
									<xsl:choose>
										<xsl:when test="number(@db2ScanCost) = number(@db2ScanCost)">
											<xsl:choose>
												<xsl:when test="@db2ScanCost &lt; 0">
													<xsl:text>Runstats not run</xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:call-template name="numberFormat">
														<xsl:with-param name="number" select="@db2ScanCost"/>
														<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
													</xsl:call-template>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Runstats not available</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</td>
							</tr>
						</table>
					
						<!-- Second Table in Relationship/Primary Key Section - 2 Fields -->
						<table class="statistics_table">
							<tr>
								<th>
									<xsl:text>Direction</xsl:text>
								</th>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@direction"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<th>
									<xsl:text>Index</xsl:text>
								</th>
								<td>
									<xsl:call-template name="booleanFormat">
										<xsl:with-param name="value" select="@index"/>
									</xsl:call-template>
								</td>
							</tr>
						</table>
					</xsl:otherwise>
				</xsl:choose>
				<!-- Third Table in Relationship/Primary Key Section - 3-5 Fields -->
				<table class="statistics_table">
				<tr>
					<th style="min-width: 95px;">
						<xsl:text>Keys per cursor</xsl:text>
					</th>
					<td>
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@keyPerCur"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
				<tr>
					<xsl:choose>
						<xsl:when test='@lookupKey &gt; 1'>
							<th>
								<xsl:text>Lookup keys</xsl:text>
							</th>
						</xsl:when>
						<xsl:otherwise>
							<th>
								<xsl:text>Lookup key</xsl:text>
							</th>
						</xsl:otherwise>
					</xsl:choose>
					<td>
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@lookupKey"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
				<tr>
					<th>
						<xsl:text>Key length</xsl:text>
					</th>
					<td>
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@keyLength"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
			</table>
			</div>
			<div>
				<!-- Fourth Table in Relationship/SQL -->
					<table class="statistics_table">
						<xsl:if test="not(@sql = '')">
						<tr>
							<th>
								<xsl:text>SQL</xsl:text>
							</th>
							<td>
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="@sql" />
								</xsl:call-template>
							</td>
						</tr>
						</xsl:if>
						<xsl:if test="not(../@whereClause = '')">
							<tr>
								<th>
									<xsl:text>Where clause</xsl:text>
								</th>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="../@whereClause" />
									</xsl:call-template>
								</td>
							</tr>
						</xsl:if>
					</table>
			</div>
		</div>
	</xsl:template>
	<!-- END relationship statistics processing -->
	
</xsl:stylesheet>

